@@ -1159,7 +1159,11 @@ class LaharFlowData(object):
     def _get_data_nc(self, LaharFlowFile, vars=None):
 
         raster = nc2xr(LaharFlowFile, vars=vars)
-        raster = raster.rename({"x_distance": "x", "y_distance": "y"})
+        coords = list(raster.coords.keys())
+        if "x_distance" in coords:
+            raster = raster.rename({"x_distance": "x"})
+        if "y_distance" in coords:
+            raster = raster.rename({"y_distance": "y"})
         raster["x"] = raster["x"] + self.utm[0]
         raster["y"] = raster["y"] + self.utm[1]
         raster.rio.write_crs(self.utmCode, inplace=True)
