@@ -6,7 +6,7 @@ import xarray as xr
 from numpy.lib.recfunctions import rename_fields as np_rename_fields
 
 
-def nc2xr(filename, var=None):
+def nc2xr(filename, vars=None, chunk_size=10):
 
     with nc.Dataset(filename, "r") as rgrp:
         attrs = rgrp.__dict__
@@ -14,19 +14,31 @@ def nc2xr(filename, var=None):
         tiles = list(rgrp.groups)
         nc_variables = list(rgrp[tiles[0]].variables)
 
-    if var is not None:
+    if vars is not None:
         drop_variables = nc_variables.copy()
-        for v in var + ["x", "y"]:
+        for v in vars + ["x", "y"]:
             drop_variables.remove(v)
     else:
         drop_variables = []
 
     data = xr.open_dataset(filename, group=tiles[0], drop_variables=drop_variables)
 
-    for t in tiles[1:]:
-        d = xr.open_dataset(filename, group=t, drop_variables=drop_variables)
+    tile_chunks = [
+        tiles[i * chunk_size : (i + 1) * chunk_size]
+        for i in range((len(tiles) + chunk_size - 1) // chunk_size)
+    ]
 
-        data = data.combine_first(d)
+    d = []
+
+    for k, chunk in enumerate(tile_chunks):
+        d.append(
+            xr.open_dataset(filename, group=chunk[0], drop_variables=drop_variables)
+        )
+        for t in chunk[1:]:
+            d_tmp = xr.open_dataset(filename, group=t, drop_variables=drop_variables)
+            d[k] = d[k].combine_first(d_tmp)
+
+    data = xr.merge(d)
 
     return data
 
